@@ -159,6 +159,7 @@ gl_journal_get_boots (GlJournal *journal)
     {
         gchar *boot_match;
         gchar *id;
+        GError *error = NULL;
         GlJournalBootID boot_id;
 
         sd_journal_flush_matches (priv->journal);
@@ -182,7 +183,13 @@ gl_journal_get_boots (GlJournal *journal)
                        g_strerror (-r));
         }
 
-        id = gl_journal_get_data (journal, "_BOOT_ID", NULL);
+        id = gl_journal_get_data (journal, "_BOOT_ID", &error);
+        if (error != NULL)
+        {
+            g_debug ("%s", error->message);
+            g_clear_error (&error);
+        }
+
         boot_match = g_strconcat ("_BOOT_ID=", id, NULL);
         boot_id.boot_match = boot_match;
         g_free (id);
@@ -413,7 +420,7 @@ _gl_journal_query_entry (GlJournal *self)
         goto out;
     }
 
-    entry->message = gl_journal_get_data (self, "MESSAGE", NULL);
+    entry->message = gl_journal_get_data (self, "MESSAGE", &error);
 
     if (error != NULL)
     {
@@ -426,19 +433,14 @@ _gl_journal_query_entry (GlJournal *self)
         goto out;
     }
 
-    priority = gl_journal_get_data (self, "PRIORITY", NULL);
+    priority = gl_journal_get_data (self, "PRIORITY", &error);
 
     if (error != NULL)
     {
-        g_warning ("%s", error->message);
+        /* Some entries do not have PRIORITY field, so use g_debug instead
+         * of g_warning*/
+        g_debug ("%s", error->message);
         g_clear_error (&error);
-        free (entry->cursor);
-        entry->cursor = NULL;
-        free (entry->catalog);
-        entry->catalog = NULL;
-        g_free (entry->message);
-        entry->message = NULL;
-        goto out;
     }
 
     entry->priority = priority ? atoi (priority) : LOG_INFO;
@@ -452,7 +454,7 @@ _gl_journal_query_entry (GlJournal *self)
         g_clear_error (&error);
     }
 
-    entry->kernel_device = gl_journal_get_data (self, "_KERNEL_DEVICE", NULL);
+    entry->kernel_device = gl_journal_get_data (self, "_KERNEL_DEVICE", &error);
 
     if (error != NULL)
     {
@@ -460,7 +462,13 @@ _gl_journal_query_entry (GlJournal *self)
         g_clear_error (&error);
     }
 
-    entry->audit_session = gl_journal_get_data (self, "_AUDIT_SESSION", NULL);
+    entry->audit_session = gl_journal_get_data (self, "_AUDIT_SESSION", &error);
+
+    if (error != NULL)
+    {
+        g_debug ("%s", error->message);
+        g_clear_error (&error);
+    }
 
     entry->transport = gl_journal_get_data (self, "_TRANSPORT", &error);
 
